/// <reference types="react" />
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
import { InputProps } from '@highlight-ui/input';
import { AvailableLocales } from './private/date-time-config';
export declare type CalendarProps = PropsWithMetadata<{
    flatpickrWrapper: React.Ref<HTMLDivElement>;
    flatpickrMountDiv: React.Ref<HTMLDivElement>;
    isOpened: boolean;
    style?: React.CSSProperties;
}>;
declare type InputPickerProps = Omit<InputProps, 'onChange' | 'value' | 'maskOptions' | 'onMaskAccept' | 'onMaskComplete' | 'prefix' | 'prefixVariant' | 'suffix' | 'autoComplete'>;
export declare type DateInputProps = InputPickerProps & PropsWithMetadata<{
    /** The locale to format the date with */
    locale: AvailableLocales;
    mode: 'time' | 'date';
    /** Minimum inclusive allowed date */
    minDate?: Date;
    /** Maximum inclusive allowed date */
    maxDate?: Date;
    withIcon?: boolean;
    /** List of the dates which are not allowed for selection */
    disabledDates?: Date[];
    /** The callback being fired on each change on the input or when a date from the calendar is selected */
    onChange?: (date: undefined | Date, inputValue: string) => void;
    /** The controlled value of the input */
    value?: Date;
}>;
export declare type DatePickerProps = Omit<DateInputProps, 'onChange' | 'mode' | 'withIcon'> & {
    /** Allows providing a custom class name to the DIV element that surrounds the text */
    className?: string;
    /** The callback being fired on each change on the input or when a date from the calendar is selected */
    onChange?: (date?: Date, inputValue?: string) => void;
    /** Should the calendar close after each selection? */
    closeOnSelect?: boolean;
    /** Should it show the calendar element when the input has focus? */
    noCalendar?: boolean;
};
export declare type RangeDatePickerProps = Omit<DateInputProps, 'onChange' | 'mode' | 'id' | 'value' | 'withIcon'> & {
    /** Allows providing a custom class name to the DIV element that surrounds the text */
    className?: string;
    /** The controlled value of the input */
    range?: [Date, Date];
    /** The callback being fired on each change on the inputs or when a range of dates from the calendar are selected */
    onChange?: (dates: [Date | undefined, Date | undefined], inputValues: [string, string]) => void;
    /** Should the calendar close after each selection? */
    closeOnSelect?: boolean;
    /** This value will be passed as id for the start range input */
    startInputId?: string;
    /** This value will be passed as id for the end range input */
    endInputId?: string;
};
declare type TimePickerInputProps = Omit<InputProps, 'onChange' | 'value' | 'onMaskAccept' | 'onMaskComplete' | 'prefix' | 'prefixVariant' | 'suffix' | 'autoComplete' | 'defaultValue' | 'min' | 'max' | 'step'> & {
    /** Allows providing a custom class name to the DIV element that surrounds the text */
    className?: string;
};
export declare type TimeInputProps = TimePickerInputProps & PropsWithMetadata<{
    /** The locale to format the time with */
    locale: AvailableLocales;
    /** The callback being fired on each change on the input or when a preset time is selected */
    onChange?: (inputValue: string) => void;
    /** The controlled value of the input */
    value?: string;
    iconName: string;
    onBlur?: (e: React.FocusEvent) => void;
}>;
export declare type ControlledTimePickerProps = TimePickerInputProps & PropsWithMetadata<{
    /** Day that should be returned in the `onChange` handler along with the time */
    day?: Date;
    /** The callback being fired on each change on the input or when a preset time is selected */
    onChange?: (date?: Date, inputValue?: string) => void;
    /** An array of time options from which the user can choose */
    presetTimes?: Date[];
    /** The controlled value of the input */
    value?: Date;
    /** The locale to format the time with */
    locale: AvailableLocales;
}>;
export declare type TimePickerProps = ControlledTimePickerProps & PropsWithMetadata<{
    /** If `defaultValue` is `Date` or `null` TimePicker act as uncontrolled ignoring `value` prop */
    defaultValue?: Date | null;
}>;
export {};
